Coverage for jbank/management/commands/test_to.py: 73%

# Coverage for jbank/management/commands/test_to.py : 73%

## 11 statements

Hot-keys on this page

r m x p toggle line displays

j k next/prev highlighted chunk

0 (zero) top of page

1 (one) first highlighted chunk

1 from pprint import pprint

2 from django.core.management.base import CommandParser

3 from jbank.parsers import parse_tiliote_statements_from_file

4 from jutil.command import SafeCommand

5

6

7 class Command(SafeCommand):

8 help = 'Parses bank account statement .TO (tiliote) files'

9

10 def add_arguments(self, parser: CommandParser):

11 parser.add_argument('path', type=str)

12

13 def do(self, *args, **options):

14 statements = parse_tiliote_statements_from_file(options['path'])

15 pprint(statements)